==> affyPara_1.6.0.zip: affyPara/doc/affyPara.R <==
###################################################
### chunk number 1: 
###################################################
library(affyPara)


###################################################
### chunk number 2: 
###################################################
library(affyPara)


###################################################
### chunk number 3: 
###################################################
library(affydata)
data(Dilution)
Dilution


###################################################
### chunk number 4: 
###################################################
cl <- makeCluster(4, type='SOCK')


###################################################
### chunk number 5: 
###################################################
stopCluster(cl)


###################################################
### chunk number 6: 
###################################################
cl <- makeCluster(2, type='SOCK')


###################################################
### chunk number 7:  eval=FALSE
###################################################
## AffyBatch <- ReadAffy()


###################################################
### chunk number 8: 
###################################################
bgcorrect.methods()


###################################################
### chunk number 9: affyBatchBGC
###################################################
affyBatchBGC <- bgCorrectPara(Dilution,
				method="rma", verbose=TRUE)


###################################################
### chunk number 10: affyBatchBGCfiles eval=FALSE
###################################################
## files <- list.celfiles(full.names=TRUE)
## affyBatchGBC <- bgCorrectPara(files, 
## 				method="rma", cluster=cl)


###################################################
### chunk number 11: affyBatchNORM
###################################################
affyBatchNORM <- normalizeAffyBatchQuantilesPara(
		Dilution, type = "pmonly", verbose=TRUE)


###################################################
### chunk number 12: affyBatchGBCfiles eval=FALSE
###################################################
## files <- list.celfiles(full.names=TRUE)
## affyBatchNORM <- normalizeAffyBatchQuantilesPara(
## 		files, type = "pmonly")


###################################################
### chunk number 13: 
###################################################
express.summary.stat.methods()
pmcorrect.methods()


###################################################
### chunk number 14: computeExprSetPara eval=FALSE
###################################################
## esset <- computeExprSetPara(
## 	Dilution,
## 	pmcorrect.method = "pmonly",
## 	summary.method = "avgdiff")


###################################################
### chunk number 15: computeExprSetParafiles eval=FALSE
###################################################
## files <- list.celfiles(full.names=TRUE)
## esset <- normalizeAffyBatchQuantilesPara(
## 	files, 
## 	pmcorrect.method = "pmonly",
## 	summary.method = "avgdiff")


###################################################
### chunk number 16: preproPara eval=FALSE
###################################################
## esset <- preproPara(
## 	Dilution, 
## 	bgcorrect = TRUE, bgcorrect.method = "rma",
## 	normalize = TRUE, normalize.method = "quantil",
## 	pmcorrect.method = "pmonly",
## 	summary.method = "avgdiff")


###################################################
### chunk number 17: preproParafiles eval=FALSE
###################################################
## files <- list.celfiles(full.names=TRUE)
## esset <- preproPara(
## 	files, 
## 	bgcorrect = TRUE, bgcorrect.method = "rma",
## 	normalize = TRUE, normalize.method = "quantil",
## 	pmcorrect.method = "pmonly",
## 	summary.method = "avgdiff")


###################################################
### chunk number 18: rmaPara eval=FALSE
###################################################
## esset <- rmaPara(Dilution)


###################################################
### chunk number 19: rmaParaFiles eval=FALSE
###################################################
## files <- list.celfiles(full.names=TRUE)
## esset <- rmaPara(files)


###################################################
### chunk number 20: qc eval=FALSE
###################################################
## boxplotPara(Dilution)
## MAplotPara(Dilution)


###################################################
### chunk number 21: distributeFiles eval=FALSE
###################################################
## path <- "tmp/CELfiles" # path at local computer system (master)
## files <- list.files(path,full.names=TRUE)
## distList <- distributeFiles(CELfiles, protocol="RCP")
## eset <- rmaPara(distList$CELfiles)


###################################################
### chunk number 22: removeDistributedFiles eval=FALSE
###################################################
## removeDistributedFiles("/usr1/tmp/CELfiles")


###################################################
### chunk number 23: identical_bgc
###################################################
affybatch1 <- bg.correct(Dilution,
		method="rma") 
 affybatch2 <- bgCorrectPara(Dilution,
		method="rma")
identical(exprs(affybatch1),exprs(affybatch2))
all.equal(exprs(affybatch1),exprs(affybatch2))


###################################################
### chunk number 24: identical_loess eval=FALSE
###################################################
## set.seed(1234)
## affybatch1 <- normalize.AffyBatch.loess(Dilution)
## set.seed(1234)
## affybatch2 <- normalizeAffyBatchLoessPara(Dilution, verbose=TRUE) 
## identical(exprs(affybatch1),exprs(affybatch2))


###################################################
### chunk number 25: 
###################################################
stopCluster()

==> affyPara_1.10.0.zip: affyPara/doc/affyPara.R <==
###################################################
### chunk number 1: 
###################################################
#line 59 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpphhW1u/R.INSTALL37aa3b7a/affyPara/inst/doc/affyPara.Rnw"
library(affyPara)


###################################################
### chunk number 2: 
###################################################
#line 117 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpphhW1u/R.INSTALL37aa3b7a/affyPara/inst/doc/affyPara.Rnw"
library(affyPara)


###################################################
### chunk number 3: 
###################################################
#line 122 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpphhW1u/R.INSTALL37aa3b7a/affyPara/inst/doc/affyPara.Rnw"
library(affydata)
data(Dilution)
Dilution


###################################################
### chunk number 4: 
###################################################
#line 139 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpphhW1u/R.INSTALL37aa3b7a/affyPara/inst/doc/affyPara.Rnw"
cl <- makeCluster(4, type='SOCK')


###################################################
### chunk number 5: 
###################################################
#line 147 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpphhW1u/R.INSTALL37aa3b7a/affyPara/inst/doc/affyPara.Rnw"
stopCluster(cl)


###################################################
### chunk number 6: 
###################################################
#line 150 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpphhW1u/R.INSTALL37aa3b7a/affyPara/inst/doc/affyPara.Rnw"
cl <- makeCluster(2, type='SOCK')


###################################################
### chunk number 7:  eval=FALSE
###################################################
## #line 177 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpphhW1u/R.INSTALL37aa3b7a/affyPara/inst/doc/affyPara.Rnw"
## AffyBatch <- ReadAffy()


###################################################
### chunk number 8: 
###################################################
#line 211 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpphhW1u/R.INSTALL37aa3b7a/affyPara/inst/doc/affyPara.Rnw"
bgcorrect.methods()


###################################################
### chunk number 9: affyBatchBGC
###################################################
#line 219 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpphhW1u/R.INSTALL37aa3b7a/affyPara/inst/doc/affyPara.Rnw"
affyBatchBGC <- bgCorrectPara(Dilution,
				method="rma", verbose=TRUE)


###################################################
### chunk number 10: affyBatchBGCfiles eval=FALSE
###################################################
## #line 227 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpphhW1u/R.INSTALL37aa3b7a/affyPara/inst/doc/affyPara.Rnw"
## files <- list.celfiles(full.names=TRUE)
## affyBatchGBC <- bgCorrectPara(files, 
## 				method="rma", cluster=cl)


###################################################
### chunk number 11: affyBatchNORM
###################################################
#line 261 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpphhW1u/R.INSTALL37aa3b7a/affyPara/inst/doc/affyPara.Rnw"
affyBatchNORM <- normalizeAffyBatchQuantilesPara(
		Dilution, type = "pmonly", verbose=TRUE)


###################################################
### chunk number 12: affyBatchGBCfiles eval=FALSE
###################################################
## #line 268 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpphhW1u/R.INSTALL37aa3b7a/affyPara/inst/doc/affyPara.Rnw"
## files <- list.celfiles(full.names=TRUE)
## affyBatchNORM <- normalizeAffyBatchQuantilesPara(
## 		files, type = "pmonly")


###################################################
### chunk number 13: 
###################################################
#line 290 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpphhW1u/R.INSTALL37aa3b7a/affyPara/inst/doc/affyPara.Rnw"
express.summary.stat.methods()
pmcorrect.methods()


###################################################
### chunk number 14: computeExprSetPara eval=FALSE
###################################################
## #line 299 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpphhW1u/R.INSTALL37aa3b7a/affyPara/inst/doc/affyPara.Rnw"
## esset <- computeExprSetPara(
## 	Dilution,
## 	pmcorrect.method = "pmonly",
## 	summary.method = "avgdiff")


###################################################
### chunk number 15: computeExprSetParafiles eval=FALSE
###################################################
## #line 308 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpphhW1u/R.INSTALL37aa3b7a/affyPara/inst/doc/affyPara.Rnw"
## files <- list.celfiles(full.names=TRUE)
## esset <- normalizeAffyBatchQuantilesPara(
## 	files, 
## 	pmcorrect.method = "pmonly",
## 	summary.method = "avgdiff")


###################################################
### chunk number 16: preproPara eval=FALSE
###################################################
## #line 334 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpphhW1u/R.INSTALL37aa3b7a/affyPara/inst/doc/affyPara.Rnw"
## esset <- preproPara(
## 	Dilution, 
## 	bgcorrect = TRUE, bgcorrect.method = "rma",
## 	normalize = TRUE, normalize.method = "quantil",
## 	pmcorrect.method = "pmonly",
## 	summary.method = "avgdiff")


###################################################
### chunk number 17: preproParafiles eval=FALSE
###################################################
## #line 348 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpphhW1u/R.INSTALL37aa3b7a/affyPara/inst/doc/affyPara.Rnw"
## files <- list.celfiles(full.names=TRUE)
## esset <- preproPara(
## 	files, 
## 	bgcorrect = TRUE, bgcorrect.method = "rma",
## 	normalize = TRUE, normalize.method = "quantil",
## 	pmcorrect.method = "pmonly",
## 	summary.method = "avgdiff")


###################################################
### chunk number 18: rmaPara eval=FALSE
###################################################
## #line 370 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpphhW1u/R.INSTALL37aa3b7a/affyPara/inst/doc/affyPara.Rnw"
## esset <- rmaPara(Dilution)


###################################################
### chunk number 19: rmaParaFiles eval=FALSE
###################################################
## #line 378 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpphhW1u/R.INSTALL37aa3b7a/affyPara/inst/doc/affyPara.Rnw"
## files <- list.celfiles(full.names=TRUE)
## esset <- rmaPara(files)


###################################################
### chunk number 20: qc eval=FALSE
###################################################
## #line 400 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpphhW1u/R.INSTALL37aa3b7a/affyPara/inst/doc/affyPara.Rnw"
## boxplotPara(Dilution)
## MAplotPara(Dilution)


###################################################
### chunk number 21: distributeFiles eval=FALSE
###################################################
## #line 417 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpphhW1u/R.INSTALL37aa3b7a/affyPara/inst/doc/affyPara.Rnw"
## path <- "tmp/CELfiles" # path at local computer system (master)
## files <- list.files(path,full.names=TRUE)
## distList <- distributeFiles(CELfiles, protocol="RCP")
## eset <- rmaPara(distList$CELfiles)


###################################################
### chunk number 22: removeDistributedFiles eval=FALSE
###################################################
## #line 430 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpphhW1u/R.INSTALL37aa3b7a/affyPara/inst/doc/affyPara.Rnw"
## removeDistributedFiles("/usr1/tmp/CELfiles")


###################################################
### chunk number 23: identical_bgc
###################################################
#line 449 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpphhW1u/R.INSTALL37aa3b7a/affyPara/inst/doc/affyPara.Rnw"
affybatch1 <- bg.correct(Dilution,
		method="rma") 
 affybatch2 <- bgCorrectPara(Dilution,
		method="rma")
identical(exprs(affybatch1),exprs(affybatch2))
all.equal(exprs(affybatch1),exprs(affybatch2))


###################################################
### chunk number 24: identical_loess eval=FALSE
###################################################
## #line 464 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpphhW1u/R.INSTALL37aa3b7a/affyPara/inst/doc/affyPara.Rnw"
## set.seed(1234)
## affybatch1 <- normalize.AffyBatch.loess(Dilution)
## set.seed(1234)
## affybatch2 <- normalizeAffyBatchLoessPara(Dilution, verbose=TRUE) 
## identical(exprs(affybatch1),exprs(affybatch2))


###################################################
### chunk number 25: 
###################################################
#line 505 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpphhW1u/R.INSTALL37aa3b7a/affyPara/inst/doc/affyPara.Rnw"
stopCluster()
